@@ -15,8 +15,9 @@
 #' @param inits Character value specifying how the initial values should be generated. Options are "fixed" or "random" or your own initial values.
 #' @param indPars Character value specifying how to summarize individual parameters. Current options are: "mean", "median", or "mode".
 #' @param saveDir Path to directory where .RData file of model output (\code{modelData}) can be saved. Leave blank if not interested.
-#' @param email Character value containing email address to send notification of completion. Leave blank if not interested. 
 #' @param modelRegressor Exporting model-based regressors? TRUE or FALSE. Currently not available for this model.
+#' @param vb             Use variational inference to approximately draw from a posterior distribution. Defaults to FALSE.
+#' @param inc_postpred Include trial-level posterior predictive simulations in model output (may greatly increase file size). Defaults to FALSE.
 #' @param adapt_delta Floating point number representing the target acceptance probability of a new sample in the MCMC chain. Must be between 0 and 1. See \bold{Details} below.
 #' @param stepsize Integer value specifying the size of each leapfrog step that the MCMC sampler can take on each new iteration. See \bold{Details} below.
 #' @param max_treedepth Integer value specifying how many leapfrog steps that the MCMC sampler can take on each new iteration. See \bold{Details} below.
@@ -32,8 +33,8 @@
 #'  \item{\code{rawdata}}{\code{"data.frame"} containing the raw data used to fit the model, as specified by the user.}
 #' }
 #' 
-#' @importFrom rstan stan rstan_options extract
-#' @importFrom mail sendmail
+#' @importFrom rstan vb sampling stan_model rstan_options extract
+#' @importFrom parallel detectCores
 #' @importFrom stats median qnorm density
 #' @importFrom utils read.table
 #'
@@ -109,22 +110,23 @@
 #' # Show the WAIC and LOOIC model fit estimates 
 #' printFit(output)
 #' }
- 
-dd_exp <- function(data          = "choose",
-                   niter         = 3000, 
-                   nwarmup       = 1000, 
-                   nchain        = 4,
-                   ncore         = 1, 
-                   nthin         = 1,
-                   inits         = "random",  
-                   indPars       = "mean", 
-                   saveDir       = NULL,
-                   email         = NULL,
-                   modelRegressor= FALSE,
-                   adapt_delta   = 0.95,
-                   stepsize      = 1,
-                   max_treedepth = 10 ) {
 
+dd_exp <- function(data           = "choose",
+                   niter          = 3000, 
+                   nwarmup        = 1000, 
+                   nchain         = 4,
+                   ncore          = 1, 
+                   nthin          = 1,
+                   inits          = "random",  
+                   indPars        = "mean", 
+                   saveDir        = NULL,
+                   modelRegressor = FALSE,
+                   vb             = FALSE,
+                   inc_postpred   = FALSE,
+                   adapt_delta    = 0.95,
+                   stepsize       = 1,
+                   max_treedepth  = 10 ) {
+  
   # Path to .stan model file
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
     stop("** Model-based regressors are not available for this model **\n")
@@ -155,7 +157,7 @@ dd_exp <- function(data          = "choose",
     rawdata = rawdata[-NA_rows, ]
     cat("The number of rows with NAs=", length(NA_rows), ". They are removed prior to modeling the data. \n", sep="")
   } 
-
+  
   # Individual Subjects
   subjList <- unique(rawdata[,"subjID"])  # list of subjects x blocks
   numSubjs <- length(subjList)  # number of subjects
@@ -167,16 +169,24 @@ dd_exp <- function(data          = "choose",
                "r", "beta", 
                "log_lik")
   
+  if (inc_postpred) {
+    POI <- c(POI, "y_pred")
+  }
+  
   modelName <- "dd_exp"
-
+  
   # Information for user
   cat("\nModel name = ", modelName, "\n")
   cat("Data file  = ", data, "\n")
   cat("\nDetails:\n")
-  cat(" # of chains                   = ", nchain, "\n")
-  cat(" # of cores used               = ", ncore, "\n")
-  cat(" # of MCMC samples (per chain) = ", niter, "\n")
-  cat(" # of burn-in samples          = ", nwarmup, "\n")
+  if (vb) {
+    cat(" # Using variational inference # \n")
+  } else {
+    cat(" # of chains                   = ", nchain, "\n")
+    cat(" # of cores used               = ", ncore, "\n")
+    cat(" # of MCMC samples (per chain) = ", niter, "\n")
+    cat(" # of burn-in samples          = ", nwarmup, "\n")
+  }
   cat(" # of subjects                 = ", numSubjs, "\n")
   
   ################################################################################
@@ -192,7 +202,7 @@ dd_exp <- function(data          = "choose",
   
   # Setting maxTrials
   maxTrials <- max(Tsubj)
-
+  
   # Information for user continued
   cat(" # of (max) trials per subject = ", maxTrials, "\n\n")
   
@@ -200,7 +210,7 @@ dd_exp <- function(data          = "choose",
   amount_later  <- array(0, c(numSubjs, maxTrials) )
   delay_sooner  <- array(0, c(numSubjs, maxTrials) )
   amount_sooner <- array(0, c(numSubjs, maxTrials) )
-  choice <- array(0, c(numSubjs, maxTrials) )
+  choice <- array(-1, c(numSubjs, maxTrials) )
   
   for (i in 1:numSubjs) {
     curSubj      <- subjList[i]
@@ -266,20 +276,30 @@ dd_exp <- function(data          = "choose",
   cat("************************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath, 
-                     data   = dataList, 
-                     pars   = POI,
-                     warmup = nwarmup,
-                     init   = genInitList, 
-                     iter   = niter, 
-                     chains = nchain,
-                     thin   = nthin,
-                     control = list(adapt_delta   = adapt_delta, 
-                                    max_treedepth = max_treedepth, 
-                                    stepsize      = stepsize) )
-  
+  m = rstan::stan_model(modelPath)
+  if (vb) {   # if variational Bayesian
+    fit = rstan::vb(m, 
+                    data   = dataList, 
+                    pars   = POI,
+                    init   = genInitList)
+  } else {
+    fit = rstan::sampling(m, 
+                          data   = dataList, 
+                          pars   = POI,
+                          warmup = nwarmup,
+                          init   = genInitList, 
+                          iter   = niter, 
+                          chains = nchain,
+                          thin   = nthin,
+                          control = list(adapt_delta   = adapt_delta, 
+                                         max_treedepth = max_treedepth, 
+                                         stepsize      = stepsize) )
+  }
   ## Extract parameters
   parVals <- rstan::extract(fit, permuted=T)
+  if (inc_postpred) {
+    parVals$y_pred[parVals$y_pred==-1] <- NA
+  }
   
   r    <- parVals$r
   beta <- parVals$beta
@@ -305,12 +325,12 @@ dd_exp <- function(data          = "choose",
   colnames(allIndPars) <- c("r", 
                             "beta", 
                             "subjID")
-
+  
   # Wrap up data into a list
   modelData        <- list(modelName, allIndPars, parVals, fit, rawdata)
   names(modelData) <- c("model", "allIndPars", "parVals", "fit", "rawdata")
   class(modelData) <- "hBayesDM"
-
+  
   # Total time of computations
   endTime  <- Sys.time()
   timeTook <- endTime - startTime
@@ -327,11 +347,6 @@ dd_exp <- function(data          = "choose",
     save(modelData, file=file.path(saveDir, paste0(modelName, "_", dataFileName, "_", timeStamp, ".RData"  ) ) )
   }
   
-  # Send email to notify user of completion
-  if (is.null(email)==F) {
-    mail::sendmail(email, paste("model=", modelName, ", fileName = ", data),
-             paste("Check ", getwd(), ". It took ", as.character.Date(timeTook), sep="") )
-  }
   # Inform user of completion
   cat("\n************************************\n")
   cat("**** Model fitting is complete! ****\n")
