@@ -15,8 +15,9 @@
 #' @param inits Character value specifying how the initial values should be generated. Options are "fixed" or "random" or your own initial values.
 #' @param indPars Character value specifying how to summarize individual parameters. Current options are: "mean", "median", or "mode".
 #' @param saveDir Path to directory where .RData file of model output (\code{modelData}) can be saved. Leave blank if not interested.
-#' @param email Character value containing email address to send notification of completion. Leave blank if not interested. 
 #' @param modelRegressor Exporting model-based regressors? TRUE or FALSE. Currently not available for this model.
+#' @param vb             Use variational inference to approximately draw from a posterior distribution. Defaults to FALSE.
+#' @param inc_postpred Include trial-level posterior predictive simulations in model output (may greatly increase file size). Defaults to FALSE.
 #' @param adapt_delta Floating point number representing the target acceptance probability of a new sample in the MCMC chain. Must be between 0 and 1. See \bold{Details} below.
 #' @param stepsize Integer value specifying the size of each leapfrog step that the MCMC sampler can take on each new iteration. See \bold{Details} below.
 #' @param max_treedepth Integer value specifying how many leapfrog steps that the MCMC sampler can take on each new iteration. See \bold{Details} below. 
@@ -32,8 +33,8 @@
 #'  \item{\code{rawdata}}{\code{"data.frame"} containing the raw data used to fit the model, as specified by the user.}
 #' }
 #' 
-#' @importFrom rstan stan rstan_options extract
-#' @importFrom mail sendmail
+#' @importFrom rstan vb sampling stan_model rstan_options extract
+#' @importFrom parallel detectCores
 #' @importFrom stats median qnorm density
 #' @importFrom utils read.table
 #'
@@ -125,8 +126,9 @@ ra_prospect <- function(data           = "choose",
                         inits          = "random",  
                         indPars        = "mean", 
                         saveDir        = NULL,
-                        email          = NULL,
                         modelRegressor = FALSE,
+                        vb             = FALSE,
+                        inc_postpred   = FALSE,
                         adapt_delta    = 0.95,
                         stepsize       = 1,
                         max_treedepth  = 10 ) {
@@ -173,18 +175,26 @@ ra_prospect <- function(data           = "choose",
                "rho" , "lambda", "tau",
                "log_lik")
   
+  if (inc_postpred) {
+    POI <- c(POI, "y_pred")
+  }
+  
   modelName <- "ra_prospect"
   
   # Information for user
   cat("\nModel name = ", modelName, "\n")
   cat("Data file  = ", data, "\n")
   cat("\nDetails:\n")
-  cat(" # of chains                   = ", nchain, "\n")
-  cat(" # of cores used               = ", ncore, "\n")
-  cat(" # of MCMC samples (per chain) = ", niter, "\n")
-  cat(" # of burn-in samples          = ", nwarmup, "\n")
+  if (vb) {
+    cat(" # Using variational inference # \n")
+  } else {
+    cat(" # of chains                   = ", nchain, "\n")
+    cat(" # of cores used               = ", ncore, "\n")
+    cat(" # of MCMC samples (per chain) = ", niter, "\n")
+    cat(" # of burn-in samples          = ", nwarmup, "\n")
+  }
   cat(" # of subjects                 = ", numSubjs, "\n")
-
+  
   ################################################################################
   # THE DATA.  ###################################################################
   ################################################################################
@@ -205,7 +215,7 @@ ra_prospect <- function(data           = "choose",
   gain    <- array(0, c(numSubjs, maxTrials) )
   loss    <- array(0, c(numSubjs, maxTrials) )
   cert    <- array(0, c(numSubjs, maxTrials))
-  gamble  <- array(0, c(numSubjs, maxTrials))
+  gamble  <- array(-1, c(numSubjs, maxTrials))
   
   for (i in 1:numSubjs) {
     curSubj      <- subjList[i]
@@ -269,20 +279,30 @@ ra_prospect <- function(data           = "choose",
   cat("************************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath, 
-                     data   = dataList, 
-                     pars   = POI,
-                     warmup = nwarmup,
-                     init   = genInitList, 
-                     iter   = niter, 
-                     chains = nchain,
-                     thin   = nthin,
-                     control = list(adapt_delta   = adapt_delta, 
-                                    max_treedepth = max_treedepth, 
-                                    stepsize      = stepsize) )
-  
+  m = rstan::stan_model(modelPath)
+  if (vb) {   # if variational Bayesian
+    fit = rstan::vb(m, 
+                    data   = dataList, 
+                    pars   = POI,
+                    init   = genInitList)
+  } else {
+    fit = rstan::sampling(m, 
+                          data   = dataList, 
+                          pars   = POI,
+                          warmup = nwarmup,
+                          init   = genInitList, 
+                          iter   = niter, 
+                          chains = nchain,
+                          thin   = nthin,
+                          control = list(adapt_delta   = adapt_delta, 
+                                         max_treedepth = max_treedepth, 
+                                         stepsize      = stepsize) )
+  }
   # Extract the Stan fit object
   parVals <- rstan::extract(fit, permuted=T)
+  if (inc_postpred) {
+    parVals$y_pred[parVals$y_pred==-1] <- NA
+  }
   
   rho    <- parVals$rho
   lambda <- parVals$lambda
@@ -313,7 +333,7 @@ ra_prospect <- function(data           = "choose",
                             "lambda", 
                             "tau", 
                             "subjID")
-
+  
   # Wrap up data into a list
   modelData        <- list(modelName, allIndPars, parVals, fit, rawdata)
   names(modelData) <- c("model", "allIndPars", "parVals", "fit", "rawdata")    
@@ -331,14 +351,10 @@ ra_prospect <- function(data           = "choose",
     currHr    <- substr(currTime, 12, 13)
     currMin   <- substr(currTime, 15, 16)
     timeStamp <- paste0(currDate, "_", currHr, "_", currMin)
-    save(modelData, file=file.path(saveDir, paste0(modelName, "_", timeStamp, ".RData"  ) ) )
+    dataFileName = sub(pattern = "(.*)\\..*$", replacement = "\\1", basename(data))
+    save(modelData, file=file.path(saveDir, paste0(modelName, "_", dataFileName, "_", timeStamp, ".RData"  ) ) )
   }
   
-  # Send email to notify user of completion
-  if (is.null(email)==F) {
-    mail::sendmail(email, paste("model=", modelName, ", fileName = ", data),
-                   paste("Check ", getwd(), ". It took ", as.character.Date(round(timeTook,2)), sep="") )
-  }
   # Inform user of completion
   cat("\n************************************\n")
   cat("**** Model fitting is complete! ****\n")
