@@ -3,6 +3,7 @@
 #' @description 
 #' A convenience function for extracting Rhat values from an hBayesDM object. Can also 
 #' check if all Rhat values are less than or equal to a specified value. 
+#' If variational inference was used, an error message will be displayed. 
 #'
 #' @param fit Model output of class \code{hBayesDM}
 #' @param less A numeric value specifying how to check Rhat values. Defaults to FALSE.
@@ -20,7 +21,11 @@ rhat <- function(fit = NULL, less = NULL) {
     stop("Error: The 'fit' object is not of class hBayesDM!")
   } else {
     summaryData <- rstan::summary(fit$fit)
-    rhatData <- data.frame(Rhat = summaryData[["summary"]][, "Rhat"])
+    if ("Rhat" %in% colnames(summaryData[["summary"]])) {
+      rhatData <- data.frame(Rhat = summaryData[["summary"]][, "Rhat"])
+    } else {
+      stop("\r The 'fit' object is estimated with variational inference! Rhat values cannot be computed.")
+    } 
   }
   if (!is.null(less)) { 
     if (all(rhatData$Rhat<=less)) {
